<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Regular News
 * @since Regular News 1.0.0
 */
if ( ! function_exists( 'regular_news_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Regular News 1.0.0
    */
    function regular_news_add_blog_section() {
    	$options = regular_news_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'regular_news_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'regular_news_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        regular_news_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'regular_news_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Regular News 1.0.0
    * @param array $input blog section details.
    */
    function regular_news_get_blog_section_details( $input ) {
        $options = regular_news_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        
        $content = array();
        switch ( $blog_content_type ) {

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => 3,
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = regular_news_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'regular_news_filter_blog_section_details', 'regular_news_get_blog_section_details' );


if ( ! function_exists( 'regular_news_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Regular News 1.0.0
   *
   */
   function regular_news_render_blog_section( $content_details = array() ) {
        $options = regular_news_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="inner-content-wrapper" class="wrapper relative clear page-section">
            <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>     

            <div class="latest-post-section-wrapper">
                <div id="primary" class="content-area <?php echo ( ! is_active_sidebar('blog-sidebar') ) ? 'blog-full-width': ''; ?>">
                    <main id="main" class="site-main" role="main">
                        <div id="latest-posts" class="relative">
                            <div class="archive-blog-wrapper clear">
                                <?php foreach ( $content_details as $content ) : ?>
                                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                                        <div class="archive-post-wrapper">
                                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                                <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                                </div><!-- .featured-image-->
                                            <?php endif; ?>

                                            <div class="entry-container">

                                                <div class="entry-meta">
                                                   <?php  
                                                        echo regular_news_author( $content['auth_id'] );
                                                        regular_news_posted_on( $content['id'] );
                                                    ?>
                                                </div>
                                               
                                                <header class="entry-header">
                                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                </header>


                                                <div class="entry-content">
                                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                                </div><!-- .entry-content -->

                                                <span class="cat-links">
                                                    <?php the_category( '', '', $content['id'] ); ?>
                                                </span><!-- .cat-links -->

                                            </div><!-- .entry-container -->
                                        </div><!-- .archive-post-wrapper -->
                                    </article>
                                <?php endforeach; ?>
                            </div><!-- .archive-blog-wrapper -->
                        </div><!-- #latest-posts -->
                    </main>
                </div><!-- #primary -->

                <?php  if ( is_active_sidebar( 'blog-sidebar' ) ) : ?>
                    <aside id="secondary" class="widget-area" role="complementary">
                        <?php dynamic_sidebar( 'blog-sidebar' ); ?> 
                    </aside>
                <?php endif; ?>
            </div><!-- .latest-post-section-wrapper -->
        </div><!-- .inner-content -->

    <?php }
endif;